/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_aB4F40Uj);
  numBytes += sLine_init(&sLine_wVk5m1tO);
  numBytes += sLine_init(&sLine_YMC7ACrZ);
  numBytes += sLine_init(&sLine_RMkKteqv);
  numBytes += sLine_init(&sLine_qAiWyODa);
  numBytes += sBiquad_init(&sBiquad_s_nYwOu8kh);
  numBytes += sLine_init(&sLine_Jzt7Ph5f);
  numBytes += sLine_init(&sLine_PxNrIp2u);
  numBytes += sLine_init(&sLine_mdkacVLD);
  numBytes += sLine_init(&sLine_y2fK15m7);
  numBytes += sBiquad_init(&sBiquad_s_uDuB02ut);
  numBytes += sLine_init(&sLine_oOlXw7Z1);
  numBytes += sLine_init(&sLine_CDGuBsmJ);
  numBytes += sLine_init(&sLine_wWUx7lql);
  numBytes += sLine_init(&sLine_GN4ERnPJ);
  numBytes += sLine_init(&sLine_xPPhsSBG);
  numBytes += sBiquad_init(&sBiquad_s_ok3X9COn);
  numBytes += sLine_init(&sLine_zFsq0XFv);
  numBytes += sLine_init(&sLine_DfoUuMms);
  numBytes += sLine_init(&sLine_MteCRcdY);
  numBytes += sLine_init(&sLine_tVy4reZj);
  numBytes += sLine_init(&sLine_YdOQ3GOb);
  numBytes += sBiquad_init(&sBiquad_s_cx4l47tR);
  numBytes += sLine_init(&sLine_IERXvBl5);
  numBytes += sLine_init(&sLine_l9z3G96G);
  numBytes += sLine_init(&sLine_3xd1UcvS);
  numBytes += sLine_init(&sLine_RKhHpgWm);
  numBytes += sBiquad_init(&sBiquad_s_edb34Mzw);
  numBytes += sLine_init(&sLine_6dhZVZUm);
  numBytes += sLine_init(&sLine_MWuCkLq6);
  numBytes += sLine_init(&sLine_NPx7xAeC);
  numBytes += sLine_init(&sLine_WGKkdpFM);
  numBytes += sLine_init(&sLine_wVJhvHXf);
  numBytes += sBiquad_init(&sBiquad_s_kOstou5l);
  numBytes += sLine_init(&sLine_P0Mfg4Ec);
  numBytes += sPhasor_k_init(&sPhasor_h17JiAIT, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_Zaq0nUzN);
  numBytes += sRPole_init(&sRPole_Zfb8sbgo);
  numBytes += sRPole_init(&sRPole_4LpyLQb4);
  numBytes += sTabhead_init(&sTabhead_Ezmxeb2k, &hTable_9SiOdIIo);
  numBytes += sTabread_init(&sTabread_bPFJZwaq, &hTable_9SiOdIIo, false);
  numBytes += sTabread_init(&sTabread_jH1l1Cgn, &hTable_9SiOdIIo, false);
  numBytes += sLine_init(&sLine_rPUDUEG3);
  numBytes += sTabhead_init(&sTabhead_6YX4vaWK, &hTable_AA4shJCi);
  numBytes += sTabread_init(&sTabread_9WAfr1QA, &hTable_AA4shJCi, false);
  numBytes += sTabread_init(&sTabread_BsqqcfDe, &hTable_AA4shJCi, false);
  numBytes += sLine_init(&sLine_zqaEaXtV);
  numBytes += sTabwrite_init(&sTabwrite_2JkYf5kj, &hTable_AA4shJCi);
  numBytes += sTabwrite_init(&sTabwrite_hmxRPtT2, &hTable_9SiOdIIo);
  numBytes += sLine_init(&sLine_5g7oCfGF);
  numBytes += sPhasor_k_init(&sPhasor_8dsSmdTm, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_cCfkwZTe);
  numBytes += sRPole_init(&sRPole_KBNLnQGW);
  numBytes += sRPole_init(&sRPole_0JzeGFdp);
  numBytes += sTabhead_init(&sTabhead_gdJ97cde, &hTable_aJGw1f4X);
  numBytes += sTabread_init(&sTabread_ieqcZOVt, &hTable_aJGw1f4X, false);
  numBytes += sTabread_init(&sTabread_6ohxTFT8, &hTable_aJGw1f4X, false);
  numBytes += sLine_init(&sLine_xcTrSe8n);
  numBytes += sTabhead_init(&sTabhead_ssymQ1vx, &hTable_xRemz9SB);
  numBytes += sTabread_init(&sTabread_BZBWt3tI, &hTable_xRemz9SB, false);
  numBytes += sTabread_init(&sTabread_kKbfvm92, &hTable_xRemz9SB, false);
  numBytes += sLine_init(&sLine_uuvGMqGL);
  numBytes += sTabwrite_init(&sTabwrite_4UrT5L2r, &hTable_xRemz9SB);
  numBytes += sTabwrite_init(&sTabwrite_YavB9NjT, &hTable_aJGw1f4X);
  numBytes += sLine_init(&sLine_gPtPQD5t);
  numBytes += sPhasor_k_init(&sPhasor_Kb883rjK, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_jjf81G4B);
  numBytes += sRPole_init(&sRPole_E1R8aDFq);
  numBytes += sRPole_init(&sRPole_qcTBumQj);
  numBytes += sTabhead_init(&sTabhead_qNaTVyBH, &hTable_2H2Gicw2);
  numBytes += sTabread_init(&sTabread_lMhRJz4N, &hTable_2H2Gicw2, false);
  numBytes += sTabread_init(&sTabread_SZSSyrUk, &hTable_2H2Gicw2, false);
  numBytes += sLine_init(&sLine_K96dbwIc);
  numBytes += sTabhead_init(&sTabhead_5OvoAjRm, &hTable_EEcgzlii);
  numBytes += sTabread_init(&sTabread_YFdOaX4j, &hTable_EEcgzlii, false);
  numBytes += sTabread_init(&sTabread_EWnt9Yeg, &hTable_EEcgzlii, false);
  numBytes += sLine_init(&sLine_fpwywKzm);
  numBytes += sTabwrite_init(&sTabwrite_oTtdnt5d, &hTable_EEcgzlii);
  numBytes += sTabwrite_init(&sTabwrite_cPNbFZsn, &hTable_2H2Gicw2);
  numBytes += cVar_init_f(&cVar_dXwF3Hdi, 0.0f);
  numBytes += cVar_init_f(&cVar_MG4yflGY, 0.0f);
  numBytes += cVar_init_f(&cVar_yGPjaGVC, 0.0f);
  numBytes += cVar_init_f(&cVar_BBW1cT6f, 0.0f);
  numBytes += cSlice_init(&cSlice_IA5zDBwp, 1, -1);
  numBytes += cVar_init_f(&cVar_5LJ64RjL, 1337.0f);
  numBytes += cVar_init_f(&cVar_KizvPPMV, 0.0f);
  numBytes += cIf_init(&cIf_sMOIIFl5, false);
  numBytes += cIf_init(&cIf_JCmxnKpe, false);
  numBytes += cBinop_init(&cBinop_m4JtjdFP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lDLb3bNS, false);
  numBytes += cBinop_init(&cBinop_XGS5Tq3k, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7Pbndc8M, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OCPM6Wfh, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_EHklSnDd, 0.0f);
  numBytes += cIf_init(&cIf_jtkCycBI, false);
  numBytes += cIf_init(&cIf_t9gltKy0, false);
  numBytes += cBinop_init(&cBinop_8hYYOno5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HO0bZGVI, false);
  numBytes += cBinop_init(&cBinop_Sfsoesbm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Q8Qy6HKO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_E9y4xpiI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_LBKpdUWs, 0.0f);
  numBytes += cIf_init(&cIf_B9YZOzXS, false);
  numBytes += cIf_init(&cIf_yFBLp9BV, false);
  numBytes += cBinop_init(&cBinop_ndxMWFFm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_dILgqhQD, false);
  numBytes += cBinop_init(&cBinop_BEKr2YzN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4zlPoyRa, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CeJlXcib, -15.0f); // __eq
  numBytes += cIf_init(&cIf_3RKbg98S, false);
  numBytes += cSlice_init(&cSlice_1RO7Neja, 1, -1);
  numBytes += cVar_init_f(&cVar_3joznFCe, 0.0f);
  numBytes += cSlice_init(&cSlice_KHBT6r5H, 1, -1);
  numBytes += cVar_init_f(&cVar_Ibb4S6Tn, 0.0f);
  numBytes += cSlice_init(&cSlice_bPahzJ5c, 1, -1);
  numBytes += cVar_init_f(&cVar_IcvhbB1T, 0.0f);
  numBytes += cSlice_init(&cSlice_C0mmjOIx, 1, -1);
  numBytes += cVar_init_f(&cVar_vUY3V6Sq, 0.313f);
  numBytes += cBinop_init(&cBinop_t6qvjZy2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ErdaIcYJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_u2sAuHkh, 0.0f);
  numBytes += cVar_init_f(&cVar_TZWrBmQo, 1337.0f);
  numBytes += cVar_init_f(&cVar_8oGELYMz, 0.3f);
  numBytes += cBinop_init(&cBinop_vyIpLkSo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gpvCnLcC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ktGlo5fd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ca1EDSIv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VdtoSP9t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qjjSnPax, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y0r1NLZq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_boF3uNv3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_eUH2kivC, 0.0f);
  numBytes += cVar_init_f(&cVar_aKYb9ty8, 1337.0f);
  numBytes += cVar_init_f(&cVar_xzRgqfHN, 0.313f);
  numBytes += cBinop_init(&cBinop_Dj6nsWAw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lbZ6r5XQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qVEOST76, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_blO6J5Yf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6WRSrgZL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_33VYx6XH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_R91RD2Ws, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lWvxVQ6n, 0.0f);
  numBytes += cVar_init_f(&cVar_YnCDq4oz, 1037.0f);
  numBytes += cVar_init_f(&cVar_KNyIzzxw, 0.4f);
  numBytes += cBinop_init(&cBinop_OqQeX7np, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BW48AnDZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CPzYabHP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fiQo7oSy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ycbyFY4Z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IbicQA3z, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_PGqFoDMh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LMDgBnFm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_emc5bTWW, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_PsFaBqZ9, 1, -1);
  numBytes += cVar_init_f(&cVar_AMn1G9fI, 1337.0f);
  numBytes += cVar_init_f(&cVar_SzA5eJeM, 0.0f);
  numBytes += cIf_init(&cIf_OOpyHr1P, false);
  numBytes += cIf_init(&cIf_cp9iT05h, false);
  numBytes += cBinop_init(&cBinop_Xk65KE2t, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4Gfg73Jk, false);
  numBytes += cBinop_init(&cBinop_GtIOUMCv, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OVin2apJ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_46R4QUcg, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_DsACsuEF, 0.0f);
  numBytes += cIf_init(&cIf_XyNndbgX, false);
  numBytes += cIf_init(&cIf_gOz3V8KT, false);
  numBytes += cBinop_init(&cBinop_WixkgURj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xRBy69TX, false);
  numBytes += cBinop_init(&cBinop_CwbcdFJ6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_b81bKY4Q, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_GQuYQpnM, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_lJcahoLI, 0.0f);
  numBytes += cIf_init(&cIf_2NCPDbwu, false);
  numBytes += cIf_init(&cIf_yszTcqeo, false);
  numBytes += cBinop_init(&cBinop_74NdtSCC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DF0VdoPC, false);
  numBytes += cBinop_init(&cBinop_5NvmBNr0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7sJ4JsLI, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ffqbQzin, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ZfWQffjO, false);
  numBytes += cSlice_init(&cSlice_SMW3IETJ, 1, -1);
  numBytes += cVar_init_f(&cVar_EGBzzZMr, 0.0f);
  numBytes += cSlice_init(&cSlice_027TWTlS, 1, -1);
  numBytes += cVar_init_f(&cVar_6fP3f8AE, 0.0f);
  numBytes += cSlice_init(&cSlice_9SK7Xn0x, 1, -1);
  numBytes += cVar_init_f(&cVar_c7R1jqbw, 0.0f);
  numBytes += cSlice_init(&cSlice_DI7bMPzX, 1, -1);
  numBytes += cVar_init_f(&cVar_F2EbRZZt, 0.313f);
  numBytes += cBinop_init(&cBinop_KReAvZb5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_AivsGqts, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yQ6Qiczx, 0.0f);
  numBytes += cVar_init_f(&cVar_jHGyrbq0, 1337.0f);
  numBytes += cVar_init_f(&cVar_06HxsWjk, 0.3f);
  numBytes += cBinop_init(&cBinop_u09389BI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Qm4FQq2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3adxg4BY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yp4NArg8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_StLd3UXt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AwCECt7B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w7dLQtLs, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_k13dIqZj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7pSo95kO, 0.0f);
  numBytes += cVar_init_f(&cVar_K2znlMqB, 1337.0f);
  numBytes += cVar_init_f(&cVar_eNPo80lx, 0.313f);
  numBytes += cBinop_init(&cBinop_dsPhVhbu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_31SJ5nAi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OAICxp2P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XAuh56gT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qnKCJ6qC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iLwXr45c, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GQJb4YkY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_HNCzW6vH, 0.0f);
  numBytes += cVar_init_f(&cVar_NdsjPjsU, 1037.0f);
  numBytes += cVar_init_f(&cVar_xlAKwqe3, 0.4f);
  numBytes += cBinop_init(&cBinop_bC6HN3kV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Bw7IFeeh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PT0KLR4i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cdVke2I6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8wr1t4ie, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SRALEIro, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Iy2UWw4f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gZfq6fEW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qCbhLUhd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OnyQM8cm, 5705.6f);
  numBytes += cVar_init_f(&cVar_OVIj0N6U, 313.3f);
  numBytes += cBinop_init(&cBinop_SBJiCI87, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_6HQ3Frx9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_HOTPFTk2, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_BqGv321I, 0.0f);
  numBytes += cVar_init_f(&cVar_WR3nE1aO, 0.0f);
  numBytes += cVar_init_f(&cVar_NZfiCrJy, 0.0f);
  numBytes += cVar_init_f(&cVar_8sCfmeor, 0.0f);
  numBytes += cVar_init_f(&cVar_Ur7hKarP, 0.0f);
  numBytes += cVar_init_f(&cVar_lXlosFqv, 0.0f);
  numBytes += cVar_init_f(&cVar_TtcbpTZt, 0.0f);
  numBytes += cVar_init_f(&cVar_MOIvVWGB, 0.0f);
  numBytes += cVar_init_f(&cVar_qwEzmZIF, 0.0f);
  numBytes += cVar_init_f(&cVar_d2hIslPb, 0.0f);
  numBytes += cVar_init_f(&cVar_UM1p4zVT, 0.0f);
  numBytes += cVar_init_f(&cVar_9jfWhuJH, 0.0f);
  numBytes += cVar_init_s(&cVar_XJinl2AH, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_BQEJomr3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CsaBpDma, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O1vPm5rT, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_bfLNrKmw, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_gi8oFntE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1hj3hTxT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wknQVfG0, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_A4zLXwfM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dxgnPMhP, 0.0f);
  numBytes += hTable_init(&hTable_AA4shJCi, 256);
  numBytes += cDelay_init(this, &cDelay_6rGeACSG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3gqK5UHS, 0.0f);
  numBytes += hTable_init(&hTable_9SiOdIIo, 256);
  numBytes += cVar_init_f(&cVar_qS2cMmBg, 14.0f);
  numBytes += cBinop_init(&cBinop_0PH07UXv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5WBO2t6t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6Eoi1uUn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PcNXVnh9, 14.0f);
  numBytes += cBinop_init(&cBinop_oW6u4x3A, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_u76IkWBj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d9UPokQz, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_zqVvdEwr, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_4uYXVF8N, 1, -1);
  numBytes += cVar_init_f(&cVar_gQ9YanAq, 0.2f);
  numBytes += cSlice_init(&cSlice_nX01bbgX, 1, -1);
  numBytes += cVar_init_f(&cVar_ORbH7O0o, 0.0f);
  numBytes += cSlice_init(&cSlice_UmWKot7x, 1, -1);
  numBytes += cVar_init_f(&cVar_gE3S6EvI, 2.0f);
  numBytes += cSlice_init(&cSlice_Ns1gK6jo, 1, -1);
  numBytes += cVar_init_f(&cVar_D5Hxb0Nw, 0.5f);
  numBytes += cVar_init_s(&cVar_fqDJewAF, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_nekstxRO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BjI8vW33, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CHvp6awN, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_F53PfuYx, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_A6LwWjAE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k4uIJ9y8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aE7aZS41, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_c31MRwQB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_KrqwUk2p, 0.0f);
  numBytes += hTable_init(&hTable_xRemz9SB, 256);
  numBytes += cDelay_init(this, &cDelay_2NswOnr3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wp12Lz90, 0.0f);
  numBytes += hTable_init(&hTable_aJGw1f4X, 256);
  numBytes += cVar_init_f(&cVar_ENQ37kdn, 14.0f);
  numBytes += cBinop_init(&cBinop_KmSPDLmC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hnfPUZpA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wrSXKCNT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SRo2qcBV, 14.0f);
  numBytes += cBinop_init(&cBinop_NnapEAPt, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_O69oYIya, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f7pxTTym, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_CKJHWWzy, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_dCBfpa2G, 1, -1);
  numBytes += cVar_init_f(&cVar_ZveilipA, 0.2f);
  numBytes += cSlice_init(&cSlice_UqveeThz, 1, -1);
  numBytes += cVar_init_f(&cVar_qbtmk3CK, 0.0f);
  numBytes += cSlice_init(&cSlice_jdMhZ9XQ, 1, -1);
  numBytes += cVar_init_f(&cVar_loZIqhCH, 2.0f);
  numBytes += cSlice_init(&cSlice_ndV0DrXJ, 1, -1);
  numBytes += cVar_init_f(&cVar_MEihEccB, 0.5f);
  numBytes += cVar_init_s(&cVar_3jvLIMQx, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_5SC49wqf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2i0574eM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LUxRULWN, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_SUyzCL4G, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_1DYUibun, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PZZSgZXT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N1uFO8QT, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_qSJlB9xE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_rnelccKX, 0.0f);
  numBytes += hTable_init(&hTable_EEcgzlii, 256);
  numBytes += cDelay_init(this, &cDelay_bccOCsII, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1b3MCamL, 0.0f);
  numBytes += hTable_init(&hTable_2H2Gicw2, 256);
  numBytes += cVar_init_f(&cVar_9Lj2uQmL, 14.0f);
  numBytes += cBinop_init(&cBinop_ABE4ZZNd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bFXRANhJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NqPcKeBk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OkYSj4CA, 14.0f);
  numBytes += cBinop_init(&cBinop_1BPsQ5CZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qA2sdsgy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uCLm1wfe, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_HFN7HFbR, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_C7fP7qzU, 1, -1);
  numBytes += cVar_init_f(&cVar_c5n3GTy8, 0.2f);
  numBytes += cSlice_init(&cSlice_3f21Z4JY, 1, -1);
  numBytes += cVar_init_f(&cVar_PExtsJSA, 0.0f);
  numBytes += cSlice_init(&cSlice_B0E0FROt, 1, -1);
  numBytes += cVar_init_f(&cVar_ePLhgVvF, 2.0f);
  numBytes += cSlice_init(&cSlice_Wex9zPBI, 1, -1);
  numBytes += cVar_init_f(&cVar_lWYPA2s7, 0.5f);
  numBytes += sVarf_init(&sVarf_HIl156L8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5v89fuST, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N9nrIX1R, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XMpIVazP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6gaHLj7u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sKeqpVl8, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_AA4shJCi);
  hTable_free(&hTable_9SiOdIIo);
  hTable_free(&hTable_xRemz9SB);
  hTable_free(&hTable_aJGw1f4X);
  hTable_free(&hTable_EEcgzlii);
  hTable_free(&hTable_2H2Gicw2);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_AA4shJCi; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_9SiOdIIo; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_xRemz9SB; // del-1397-flanger-r
    case 0x578173CB: return &hTable_aJGw1f4X; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_EEcgzlii; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_2H2Gicw2; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yVSMKXA3_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zsO3VpAy_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tm1lJzLj_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aJcDJ3Mr_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0vdm41Q9_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d5bVQxxh_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5HPRMv1O_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_va9ftMeo_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tr3uZITp_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_36hcZHRl_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cigezggC_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p8RnUOsE_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nGopQ7J9_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yx2Y9VaO_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zgj9QWw3_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gIX4wRow_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4KJ2adqs_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lxP38UvK_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCcxOULd_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RCkb9ZQS_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sI35VSli_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fOKEj4vP_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2zfhajvu_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SNEnHwub_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uXrSWi9A_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6VVhWLY5_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sKbARoA3_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9yaPa3lx_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Bu4nxAI_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eLHe9x0h_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2ygR4zOu_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UGhSDnkl_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mTWlf0EL_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uMq0VuN2_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wWOL0tLu_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tbXQfdkA_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_up7NDajh_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zjSDQfJs_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rr20Jpr7_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n3DqH6y2_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZMBbfcuo_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CsdC4Iwq_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qrdbZs8k_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LcEUblRw_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_at7vqOdu_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ePUamXjN_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gPlX2Eji_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4QYjJc1x_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DsJtSQ8A_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9gCY3PGs_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_awxJEKg6_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zgbxyvpM_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8L9V06NE_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8ugMUsqt_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jXZXLAB9_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_exkgaWNg_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9fNEqTEz_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_dXwF3Hdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TYiTbqQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_MG4yflGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O3mjKwYx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_yGPjaGVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_msazJMHt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_BBW1cT6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WoLfuJk8_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8hcRP2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o91ubIxh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vw9Oql5f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_z6uzOfDp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IA5zDBwp, 0, m, &cSlice_IA5zDBwp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EUhm1RlT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_IA5zDBwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PG5WGhmi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PG5WGhmi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5LJ64RjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PG5WGhmi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_PG5WGhmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qCcxOULd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_KizvPPMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Bj32TH1A_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sMOIIFl5, 0, m, &cIf_sMOIIFl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_sMOIIFl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FSvCIUsX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_JCmxnKpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Inbk7Mwb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WhwXJpQr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_r3poTAUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4JtjdFP, HV_BINOP_POW, 0, m, &cBinop_m4JtjdFP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m4JtjdFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lDLb3bNS, 0, m, &cIf_lDLb3bNS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i55QcWSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IP7jk5A2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_isB2TkwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JCmxnKpe, 0, m, &cIf_JCmxnKpe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_U5Ffdnax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9Z1Rl9XB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9Z1Rl9XB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JCmxnKpe, 1, m, &cIf_JCmxnKpe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WhwXJpQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_i55QcWSL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Inbk7Mwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lDLb3bNS, 0, m, &cIf_lDLb3bNS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IP7jk5A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4JtjdFP, HV_BINOP_POW, 1, m, &cBinop_m4JtjdFP_sendMessage);
  cMsg_r3poTAUs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_lDLb3bNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_PGqFoDMh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Bj32TH1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sMOIIFl5, 1, m, &cIf_sMOIIFl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FSvCIUsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Pbndc8M, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7Pbndc8M_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OCPM6Wfh, HV_BINOP_EQ, 1, m, &cBinop_OCPM6Wfh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kcEyoIvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGS5Tq3k, HV_BINOP_ADD, 0, m, &cBinop_XGS5Tq3k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XGS5Tq3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U5Ffdnax_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_isB2TkwQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7Pbndc8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lDLb3bNS, 1, m, &cIf_lDLb3bNS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OCPM6Wfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WEUdyyeP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WEUdyyeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PGqFoDMh, m);
}

void Heavy_WSTD_FL3NGR::cCast_KfS1DNmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGS5Tq3k, HV_BINOP_ADD, 1, m, &cBinop_XGS5Tq3k_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Pbndc8M, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7Pbndc8M_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OCPM6Wfh, HV_BINOP_EQ, 0, m, &cBinop_OCPM6Wfh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3LUzS1RF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KizvPPMV, 0, m, &cVar_KizvPPMV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XQmvvPEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kcEyoIvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_EHklSnDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DXa7EHc0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jtkCycBI, 0, m, &cIf_jtkCycBI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_jtkCycBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Vh2HaENt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_t9gltKy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZvQuFc4c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tE3t1wqT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Nj3P4ynk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8hYYOno5, HV_BINOP_POW, 0, m, &cBinop_8hYYOno5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8hYYOno5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HO0bZGVI, 0, m, &cIf_HO0bZGVI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNAEjWML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_4wo9lkG6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XTKVWgQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t9gltKy0, 0, m, &cIf_t9gltKy0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wKDkGaNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4o9aTNUL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4o9aTNUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t9gltKy0, 1, m, &cIf_t9gltKy0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tE3t1wqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gNAEjWML_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZvQuFc4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HO0bZGVI, 0, m, &cIf_HO0bZGVI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4wo9lkG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8hYYOno5, HV_BINOP_POW, 1, m, &cBinop_8hYYOno5_sendMessage);
  cMsg_Nj3P4ynk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_HO0bZGVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KbWsKAIK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pdPNMcv0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ywm25Nim_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_DXa7EHc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jtkCycBI, 1, m, &cIf_jtkCycBI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Vh2HaENt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q8Qy6HKO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Q8Qy6HKO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E9y4xpiI, HV_BINOP_EQ, 1, m, &cBinop_E9y4xpiI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tOP5tLJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sfsoesbm, HV_BINOP_ADD, 0, m, &cBinop_Sfsoesbm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sfsoesbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wKDkGaNT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XTKVWgQc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q8Qy6HKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HO0bZGVI, 1, m, &cIf_HO0bZGVI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E9y4xpiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YDtnqisl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YDtnqisl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KbWsKAIK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pdPNMcv0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ywm25Nim_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_p1lTNt9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sfsoesbm, HV_BINOP_ADD, 1, m, &cBinop_Sfsoesbm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q8Qy6HKO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Q8Qy6HKO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E9y4xpiI, HV_BINOP_EQ, 0, m, &cBinop_E9y4xpiI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_snOvMA3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EHklSnDd, 0, m, &cVar_EHklSnDd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lvqElil3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOP5tLJn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LBKpdUWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ww3d8pIj_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_B9YZOzXS, 0, m, &cIf_B9YZOzXS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_B9YZOzXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J5GclOYZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_yFBLp9BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bcbiT1r4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0OMqL347_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_fhi9Q0Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndxMWFFm, HV_BINOP_POW, 0, m, &cBinop_ndxMWFFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ndxMWFFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dILgqhQD, 0, m, &cIf_dILgqhQD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F6fTfcWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JAXTLKsr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HTZ8Q6OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yFBLp9BV, 0, m, &cIf_yFBLp9BV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FKhE2gYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LQhijmYY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LQhijmYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yFBLp9BV, 1, m, &cIf_yFBLp9BV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0OMqL347_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_F6fTfcWF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bcbiT1r4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dILgqhQD, 0, m, &cIf_dILgqhQD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JAXTLKsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndxMWFFm, HV_BINOP_POW, 1, m, &cBinop_ndxMWFFm_sendMessage);
  cMsg_fhi9Q0Wa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_dILgqhQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_emc5bTWW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Ww3d8pIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B9YZOzXS, 1, m, &cIf_B9YZOzXS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J5GclOYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4zlPoyRa, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4zlPoyRa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CeJlXcib, HV_BINOP_EQ, 1, m, &cBinop_CeJlXcib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O86v15KJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEKr2YzN, HV_BINOP_ADD, 0, m, &cBinop_BEKr2YzN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BEKr2YzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FKhE2gYW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HTZ8Q6OS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4zlPoyRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dILgqhQD, 1, m, &cIf_dILgqhQD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CeJlXcib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v1O275Pj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_v1O275Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_emc5bTWW, m);
}

void Heavy_WSTD_FL3NGR::cCast_3yBDYsCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEKr2YzN, HV_BINOP_ADD, 1, m, &cBinop_BEKr2YzN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4zlPoyRa, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4zlPoyRa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CeJlXcib, HV_BINOP_EQ, 0, m, &cBinop_CeJlXcib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s4txK3Gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LBKpdUWs, 0, m, &cVar_LBKpdUWs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nd7eZphD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O86v15KJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_3RKbg98S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_LMDgBnFm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PoZEBCOp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1RO7Neja, 0, m, &cSlice_1RO7Neja_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KhkLt271_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1RO7Neja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wAAmh7CW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wAAmh7CW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3joznFCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wAAmh7CW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wAAmh7CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4KJ2adqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KhkLt271_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KHBT6r5H, 0, m, &cSlice_KHBT6r5H_sendMessage);
      break;
    }
    default: {
      cSwitchcase_z6uzOfDp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_KHBT6r5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cO87fuGV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cO87fuGV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Ibb4S6Tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cO87fuGV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cO87fuGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sI35VSli_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EUhm1RlT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bPahzJ5c, 0, m, &cSlice_bPahzJ5c_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Xh6yBKAp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bPahzJ5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tImPzBUg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tImPzBUg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_IcvhbB1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tImPzBUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_tImPzBUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lxP38UvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Xh6yBKAp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C0mmjOIx, 0, m, &cSlice_C0mmjOIx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_C0mmjOIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RfteGmRA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RfteGmRA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_vUY3V6Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RfteGmRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RfteGmRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RCkb9ZQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pwUQNEhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aB4F40Uj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Mvc3sZcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wVk5m1tO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9pNq0QFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YMC7ACrZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_c9QmydNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RMkKteqv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ySprYtyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qAiWyODa, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Wt8NnjjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Bs6w3uwu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Bs6w3uwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6qvjZy2, HV_BINOP_DIVIDE, 1, m, &cBinop_t6qvjZy2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fIo8K7t5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_KbireMnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_uHsGORkj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tsSLarro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_KbireMnO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uHsGORkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t6qvjZy2, HV_BINOP_DIVIDE, 0, m, &cBinop_t6qvjZy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fIo8K7t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tsSLarro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_t6qvjZy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErdaIcYJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_ErdaIcYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ErdaIcYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EnocZa8V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jYBBPAy0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yimMOAif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fYz9xeyK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_mX7RdiJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Cb4739de_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IMxImxBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qKlcU5wS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qKlcU5wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErdaIcYJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_ErdaIcYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zIfqsjga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9euOb8LB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9euOb8LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tM7JlXMB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yMvcMVTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u2sAuHkh, 1, m, &cVar_u2sAuHkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_u2sAuHkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PCDysXI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2SWdDNSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpvCnLcC, HV_BINOP_MULTIPLY, 1, m, &cBinop_gpvCnLcC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Npxs9Mg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2SWdDNSo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CgwzsLgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZqUHOSA1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZqUHOSA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktGlo5fd, HV_BINOP_MULTIPLY, 1, m, &cBinop_ktGlo5fd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bpe9NDB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ca1EDSIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ca1EDSIv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TMQso3wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Bpe9NDB5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v4ZFJWJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VdtoSP9t, HV_BINOP_MULTIPLY, 1, m, &cBinop_VdtoSP9t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yiXJyg5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8afvZCvo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8afvZCvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qjjSnPax, HV_BINOP_MULTIPLY, 1, m, &cBinop_qjjSnPax_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TZWrBmQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6M7ciByI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IMxImxBg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zcd9sL0D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8oGELYMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zIfqsjga_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jYBBPAy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mX7RdiJd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EnocZa8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yimMOAif_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_fYz9xeyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SNEnHwub_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Cb4739de_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2zfhajvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JnAkz4MB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fOKEj4vP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tM7JlXMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QamsbLJy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QamsbLJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyIpLkSo, HV_BINOP_MULTIPLY, 1, m, &cBinop_vyIpLkSo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vyIpLkSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_h8Pxlb9C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h8Pxlb9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JnAkz4MB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PCDysXI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wWjLLNgh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wWjLLNgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PLrKAjcq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cEwZrl8Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E9GVNFaC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TN2trMfv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UXsYeYxP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tZO69w0y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gpvCnLcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pwUQNEhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ktGlo5fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mvc3sZcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ca1EDSIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9pNq0QFj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VdtoSP9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c9QmydNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qjjSnPax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ySprYtyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_TCqTaxgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TZWrBmQo, 0, m, &cVar_TZWrBmQo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GdeKyIXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8oGELYMz, 1, m, &cVar_8oGELYMz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UXsYeYxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktGlo5fd, HV_BINOP_MULTIPLY, 0, m, &cBinop_ktGlo5fd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cEwZrl8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qjjSnPax, HV_BINOP_MULTIPLY, 0, m, &cBinop_qjjSnPax_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TN2trMfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ca1EDSIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ca1EDSIv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PLrKAjcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_tZO69w0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpvCnLcC, HV_BINOP_MULTIPLY, 0, m, &cBinop_gpvCnLcC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E9GVNFaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VdtoSP9t, HV_BINOP_MULTIPLY, 0, m, &cBinop_VdtoSP9t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Zcd9sL0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u2sAuHkh, 0, m, &cVar_u2sAuHkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6M7ciByI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8oGELYMz, 0, m, &cVar_8oGELYMz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KAY4TFNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jzt7Ph5f, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LLcTHiOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PxNrIp2u, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eS0dOEyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mdkacVLD, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ez24SWiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y2fK15m7, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_tPaBsBIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EbRa1XB6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EbRa1XB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0r1NLZq, HV_BINOP_DIVIDE, 1, m, &cBinop_y0r1NLZq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IT0SXwDU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yURStlv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8BJDrcFP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_orjZCBRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_yURStlv9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8BJDrcFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0r1NLZq, HV_BINOP_DIVIDE, 0, m, &cBinop_y0r1NLZq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IT0SXwDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_orjZCBRg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_y0r1NLZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_boF3uNv3, HV_BINOP_MULTIPLY, 1, m, &cBinop_boF3uNv3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_boF3uNv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ktWSxNI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HNylFei9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_MjfRjVmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NuXiqjFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_bi6aLof1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CsmiR82Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_92kRJAWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_nT9c52jM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nT9c52jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_boF3uNv3, HV_BINOP_MULTIPLY, 0, m, &cBinop_boF3uNv3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XKntc57v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VJ3yosrT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VJ3yosrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GbVf0pqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YTfWLSXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVEOST76, HV_BINOP_MULTIPLY, 1, m, &cBinop_qVEOST76_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g33rHdUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eUH2kivC, 1, m, &cVar_eUH2kivC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QytFu2LT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_blO6J5Yf, HV_BINOP_MULTIPLY, 1, m, &cBinop_blO6J5Yf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zEJCw4aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5NsZTdle_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5NsZTdle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WRSrgZL, HV_BINOP_MULTIPLY, 1, m, &cBinop_6WRSrgZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_eUH2kivC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aPNzLaJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_aKYb9ty8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e3HZ3QiO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_92kRJAWQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kbPLNscK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xzRgqfHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_XKntc57v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HNylFei9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bi6aLof1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7ktWSxNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MjfRjVmG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_NuXiqjFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sKbARoA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CsmiR82Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6VVhWLY5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xtbei5dQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uXrSWi9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GbVf0pqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_l0UsfnFl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l0UsfnFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dj6nsWAw, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dj6nsWAw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dj6nsWAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YMISiBQR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YMISiBQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xtbei5dQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aPNzLaJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fSxdv8nQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fSxdv8nQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B5jAw15a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GN0tAu7s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_izj5EOyK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9NR5hvmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lbZ6r5XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KAY4TFNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qVEOST76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LLcTHiOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_blO6J5Yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eS0dOEyZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6WRSrgZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ez24SWiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Rcr0eHnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aKYb9ty8, 0, m, &cVar_aKYb9ty8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3dTubaY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xzRgqfHN, 1, m, &cVar_xzRgqfHN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kbPLNscK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eUH2kivC, 0, m, &cVar_eUH2kivC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_e3HZ3QiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xzRgqfHN, 0, m, &cVar_xzRgqfHN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9NR5hvmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbZ6r5XQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_lbZ6r5XQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B5jAw15a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WRSrgZL, HV_BINOP_MULTIPLY, 0, m, &cBinop_6WRSrgZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_izj5EOyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qVEOST76, HV_BINOP_MULTIPLY, 0, m, &cBinop_qVEOST76_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GN0tAu7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_blO6J5Yf, HV_BINOP_MULTIPLY, 0, m, &cBinop_blO6J5Yf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_snRcwO7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oOlXw7Z1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XsqMucdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CDGuBsmJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WHgsYKMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wWUx7lql, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_09JwHmMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GN4ERnPJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_buV5GxMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xPPhsSBG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HHNLpC8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3RqW6W6k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3RqW6W6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_33VYx6XH, HV_BINOP_DIVIDE, 1, m, &cBinop_33VYx6XH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DwuHkLfJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_tB1xfyaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_M5S3sY5U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zQBJp7Ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tB1xfyaN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M5S3sY5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_33VYx6XH, HV_BINOP_DIVIDE, 0, m, &cBinop_33VYx6XH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DwuHkLfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zQBJp7Ob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_33VYx6XH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R91RD2Ws, HV_BINOP_MULTIPLY, 1, m, &cBinop_R91RD2Ws_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R91RD2Ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jKQ1rpVv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K8uRLcBw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_IXyQlrEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_H858xtL5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_MQSzxos3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1ez8Oj16_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zC1Hnnjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_BFSzjudf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BFSzjudf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R91RD2Ws, HV_BINOP_MULTIPLY, 0, m, &cBinop_R91RD2Ws_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5LKNSOKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8X5r7tvt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8X5r7tvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h5PAOR5i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZobBdJmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BW48AnDZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_BW48AnDZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MpXvrXnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_szDCGfcA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_szDCGfcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZobBdJmB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8gOCXTDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3Pn2wmpB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3Pn2wmpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CPzYabHP, HV_BINOP_MULTIPLY, 1, m, &cBinop_CPzYabHP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IMFF1WSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fiQo7oSy, HV_BINOP_MULTIPLY, 1, m, &cBinop_fiQo7oSy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iD6yjPSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eoe071jW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eoe071jW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IMFF1WSs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wByl5ad4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lWvxVQ6n, 1, m, &cVar_lWvxVQ6n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iDlM9ezX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ycbyFY4Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_ycbyFY4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cm0bPX6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bCeamDOy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bCeamDOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbicQA3z, HV_BINOP_MULTIPLY, 1, m, &cBinop_IbicQA3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_lWvxVQ6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_06tjjgcA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_YnCDq4oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DctABAUl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_zC1Hnnjk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fbI9PlLC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KNyIzzxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5LKNSOKM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K8uRLcBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_MQSzxos3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jKQ1rpVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IXyQlrEv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_H858xtL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eLHe9x0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_1ez8Oj16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7Bu4nxAI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_U9Qebw3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9yaPa3lx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_h5PAOR5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hQCtdnyX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hQCtdnyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OqQeX7np, HV_BINOP_MULTIPLY, 1, m, &cBinop_OqQeX7np_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OqQeX7np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OcZkYti5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OcZkYti5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U9Qebw3H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_06tjjgcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QnP47Mt3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QnP47Mt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mrtkmcfa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UDTBB15Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UyhYv7V7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pHgUz3nx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7R8VIgJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YRTt8Zhw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BW48AnDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_snRcwO7w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CPzYabHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XsqMucdg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fiQo7oSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WHgsYKMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ycbyFY4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_09JwHmMN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IbicQA3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_buV5GxMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_qoMoNanU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YnCDq4oz, 0, m, &cVar_YnCDq4oz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kXUV80yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KNyIzzxw, 1, m, &cVar_KNyIzzxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7R8VIgJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CPzYabHP, HV_BINOP_MULTIPLY, 0, m, &cBinop_CPzYabHP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UDTBB15Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbicQA3z, HV_BINOP_MULTIPLY, 0, m, &cBinop_IbicQA3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pHgUz3nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fiQo7oSy, HV_BINOP_MULTIPLY, 0, m, &cBinop_fiQo7oSy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mrtkmcfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_YRTt8Zhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BW48AnDZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_BW48AnDZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UyhYv7V7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ycbyFY4Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_ycbyFY4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fbI9PlLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lWvxVQ6n, 0, m, &cVar_lWvxVQ6n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DctABAUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KNyIzzxw, 0, m, &cVar_KNyIzzxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KbWsKAIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3RKbg98S, 1, m, &cIf_3RKbg98S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hGABym8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LMDgBnFm, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pdPNMcv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hGABym8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ywm25Nim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3RKbg98S, 0, m, &cIf_3RKbg98S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_hehQ8Uhw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PsFaBqZ9, 0, m, &cSlice_PsFaBqZ9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NSyUX543_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PsFaBqZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wT7dctWK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wT7dctWK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_AMn1G9fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wT7dctWK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wT7dctWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mTWlf0EL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SzA5eJeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lguH8ZLN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_OOpyHr1P, 0, m, &cIf_OOpyHr1P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_OOpyHr1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tcMhvEeX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_cp9iT05h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_30QpvaDE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tMBGloZe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_8lcUDnoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xk65KE2t, HV_BINOP_POW, 0, m, &cBinop_Xk65KE2t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Xk65KE2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4Gfg73Jk, 0, m, &cIf_4Gfg73Jk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QoRA39Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fZaQdkub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_47n7DdnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cp9iT05h, 0, m, &cIf_cp9iT05h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9LjgjUUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_btM4RU2s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_btM4RU2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cp9iT05h, 1, m, &cIf_cp9iT05h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tMBGloZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_QoRA39Mi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_30QpvaDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4Gfg73Jk, 0, m, &cIf_4Gfg73Jk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fZaQdkub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xk65KE2t, HV_BINOP_POW, 1, m, &cBinop_Xk65KE2t_sendMessage);
  cMsg_8lcUDnoe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_4Gfg73Jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Iy2UWw4f, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lguH8ZLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OOpyHr1P, 1, m, &cIf_OOpyHr1P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tcMhvEeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVin2apJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OVin2apJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_46R4QUcg, HV_BINOP_EQ, 1, m, &cBinop_46R4QUcg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MLZWYHqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtIOUMCv, HV_BINOP_ADD, 0, m, &cBinop_GtIOUMCv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GtIOUMCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9LjgjUUu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_47n7DdnC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OVin2apJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4Gfg73Jk, 1, m, &cIf_4Gfg73Jk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_46R4QUcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8pvYAiEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8pvYAiEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Iy2UWw4f, m);
}

void Heavy_WSTD_FL3NGR::cCast_pIjGvLTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtIOUMCv, HV_BINOP_ADD, 1, m, &cBinop_GtIOUMCv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVin2apJ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OVin2apJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_46R4QUcg, HV_BINOP_EQ, 0, m, &cBinop_46R4QUcg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dYNdHD6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SzA5eJeM, 0, m, &cVar_SzA5eJeM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vHZfguQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MLZWYHqp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_DsACsuEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_T6fmnPHH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XyNndbgX, 0, m, &cIf_XyNndbgX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_XyNndbgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FhM9N2Zw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_gOz3V8KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_359Nv17V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_771hZAzr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_7CPxNrkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WixkgURj, HV_BINOP_POW, 0, m, &cBinop_WixkgURj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WixkgURj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xRBy69TX, 0, m, &cIf_xRBy69TX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sON7jqB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DekoQ6bz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a7v9g7aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_c4RTqBk6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PiepeqJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gOz3V8KT, 0, m, &cIf_gOz3V8KT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c4RTqBk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gOz3V8KT, 1, m, &cIf_gOz3V8KT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_771hZAzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sON7jqB9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_359Nv17V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xRBy69TX, 0, m, &cIf_xRBy69TX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DekoQ6bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WixkgURj, HV_BINOP_POW, 1, m, &cBinop_WixkgURj_sendMessage);
  cMsg_7CPxNrkH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_xRBy69TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kaEbzm0c_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dSnNvB9v_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Xwnp6mC2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_T6fmnPHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XyNndbgX, 1, m, &cIf_XyNndbgX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FhM9N2Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b81bKY4Q, HV_BINOP_GREATER_THAN, 1, m, &cBinop_b81bKY4Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQuYQpnM, HV_BINOP_EQ, 1, m, &cBinop_GQuYQpnM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zfeggvYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CwbcdFJ6, HV_BINOP_ADD, 0, m, &cBinop_CwbcdFJ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CwbcdFJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a7v9g7aR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PiepeqJk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b81bKY4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xRBy69TX, 1, m, &cIf_xRBy69TX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GQuYQpnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k45AEEii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_k45AEEii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kaEbzm0c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dSnNvB9v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Xwnp6mC2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iJWrGrm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zfeggvYG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_5LzGI8Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CwbcdFJ6, HV_BINOP_ADD, 1, m, &cBinop_CwbcdFJ6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b81bKY4Q, HV_BINOP_GREATER_THAN, 0, m, &cBinop_b81bKY4Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQuYQpnM, HV_BINOP_EQ, 0, m, &cBinop_GQuYQpnM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8LXI6iBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DsACsuEF, 0, m, &cVar_DsACsuEF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_lJcahoLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xFIl0Wrd_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2NCPDbwu, 0, m, &cIf_2NCPDbwu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_2NCPDbwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_I99cG7Lr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_yszTcqeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LboLqrfp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4sM3y7TN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_YBiwI9ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_74NdtSCC, HV_BINOP_POW, 0, m, &cBinop_74NdtSCC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_74NdtSCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DF0VdoPC, 0, m, &cIf_DF0VdoPC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gCLkZj2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Sw9996kN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w5qNYrzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eHAEaLiV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TynkP44X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yszTcqeo, 0, m, &cIf_yszTcqeo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eHAEaLiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yszTcqeo, 1, m, &cIf_yszTcqeo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4sM3y7TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gCLkZj2G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LboLqrfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DF0VdoPC, 0, m, &cIf_DF0VdoPC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sw9996kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74NdtSCC, HV_BINOP_POW, 1, m, &cBinop_74NdtSCC_sendMessage);
  cMsg_YBiwI9ad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_DF0VdoPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qCbhLUhd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_xFIl0Wrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2NCPDbwu, 1, m, &cIf_2NCPDbwu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I99cG7Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sJ4JsLI, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7sJ4JsLI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ffqbQzin, HV_BINOP_EQ, 1, m, &cBinop_ffqbQzin_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KC4yWFWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5NvmBNr0, HV_BINOP_ADD, 0, m, &cBinop_5NvmBNr0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5NvmBNr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w5qNYrzM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TynkP44X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7sJ4JsLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DF0VdoPC, 1, m, &cIf_DF0VdoPC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ffqbQzin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xgIdATuR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xgIdATuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qCbhLUhd, m);
}

void Heavy_WSTD_FL3NGR::cCast_iDacmOcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lJcahoLI, 0, m, &cVar_lJcahoLI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uWk4FCrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KC4yWFWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_6H205tuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5NvmBNr0, HV_BINOP_ADD, 1, m, &cBinop_5NvmBNr0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sJ4JsLI, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7sJ4JsLI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ffqbQzin, HV_BINOP_EQ, 0, m, &cBinop_ffqbQzin_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ZfWQffjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_gZfq6fEW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Bvo0NhnV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SMW3IETJ, 0, m, &cSlice_SMW3IETJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FJ6ob6Zg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SMW3IETJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RcHm7cAX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RcHm7cAX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_EGBzzZMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RcHm7cAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RcHm7cAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2ygR4zOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FJ6ob6Zg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_027TWTlS, 0, m, &cSlice_027TWTlS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hehQ8Uhw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_027TWTlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dIxSOLEa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dIxSOLEa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6fP3f8AE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dIxSOLEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_dIxSOLEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wWOL0tLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NSyUX543_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9SK7Xn0x, 0, m, &cSlice_9SK7Xn0x_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fhAuTByw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_9SK7Xn0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fbKq9ZU3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fbKq9ZU3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_c7R1jqbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fbKq9ZU3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_fbKq9ZU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UGhSDnkl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_fhAuTByw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DI7bMPzX, 0, m, &cSlice_DI7bMPzX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_DI7bMPzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jc6CenIm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jc6CenIm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_F2EbRZZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jc6CenIm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jc6CenIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uMq0VuN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_w4WWcCo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zFsq0XFv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_591095AW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DfoUuMms, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LTFWWgF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MteCRcdY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZU7VID7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tVy4reZj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MPbtqsoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YdOQ3GOb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PLkO6NNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sh65zYPt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_sh65zYPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KReAvZb5, HV_BINOP_DIVIDE, 1, m, &cBinop_KReAvZb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dS08Pgse_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_SePaAm8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oP7Rx8Hi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KfkQduh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_SePaAm8n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oP7Rx8Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KReAvZb5, HV_BINOP_DIVIDE, 0, m, &cBinop_KReAvZb5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dS08Pgse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KfkQduh5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KReAvZb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AivsGqts, HV_BINOP_MULTIPLY, 1, m, &cBinop_AivsGqts_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AivsGqts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cHH3JADe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CQJ6mcxj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_rNIKSbK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AxwSpNa7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_HDlrKkhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TBfMGtj0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1q2f3yCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_V87KFET7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V87KFET7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AivsGqts, HV_BINOP_MULTIPLY, 0, m, &cBinop_AivsGqts_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SyLN8eQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ov6aZ1VR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ov6aZ1VR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8QsVtJM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Z2ZVs8XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQ6Qiczx, 1, m, &cVar_yQ6Qiczx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_yQ6Qiczx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ig67uT4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LPDKW2dA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Qm4FQq2, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Qm4FQq2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_akjr4fUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LPDKW2dA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rJesLAQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iPEDSjOV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iPEDSjOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3adxg4BY, HV_BINOP_MULTIPLY, 1, m, &cBinop_3adxg4BY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PwqzJ8Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yp4NArg8, HV_BINOP_MULTIPLY, 1, m, &cBinop_yp4NArg8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g3uTi0qF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PwqzJ8Dx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U2IQOfig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StLd3UXt, HV_BINOP_MULTIPLY, 1, m, &cBinop_StLd3UXt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jANMMVyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XzMhdXOl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XzMhdXOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwCECt7B, HV_BINOP_MULTIPLY, 1, m, &cBinop_AwCECt7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_jHGyrbq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z0fha9NN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_1q2f3yCl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M4bqeEl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_06HxsWjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SyLN8eQS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cHH3JADe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rNIKSbK2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CQJ6mcxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HDlrKkhF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_AxwSpNa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zjSDQfJs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_TBfMGtj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_up7NDajh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f0sDSf53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tbXQfdkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8QsVtJM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7KE8erXf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7KE8erXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u09389BI, HV_BINOP_MULTIPLY, 1, m, &cBinop_u09389BI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u09389BI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VwpB9qIW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VwpB9qIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f0sDSf53_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ig67uT4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vwod1WNA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vwod1WNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0QITrAvo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GCnRZPYg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yJPxYPSg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OOM8g7pc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HAWYsOGl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fTu8W3UB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Qm4FQq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w4WWcCo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3adxg4BY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_591095AW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yp4NArg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LTFWWgF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_StLd3UXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZU7VID7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AwCECt7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MPbtqsoo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_x4xdnHHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_06HxsWjk, 1, m, &cVar_06HxsWjk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CBryJ9CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jHGyrbq0, 0, m, &cVar_jHGyrbq0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HAWYsOGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3adxg4BY, HV_BINOP_MULTIPLY, 0, m, &cBinop_3adxg4BY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GCnRZPYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AwCECt7B, HV_BINOP_MULTIPLY, 0, m, &cBinop_AwCECt7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OOM8g7pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yp4NArg8, HV_BINOP_MULTIPLY, 0, m, &cBinop_yp4NArg8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0QITrAvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_fTu8W3UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Qm4FQq2, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Qm4FQq2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yJPxYPSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StLd3UXt, HV_BINOP_MULTIPLY, 0, m, &cBinop_StLd3UXt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_M4bqeEl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQ6Qiczx, 0, m, &cVar_yQ6Qiczx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_z0fha9NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_06HxsWjk, 0, m, &cVar_06HxsWjk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ieyzsTKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IERXvBl5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_tLh6yK3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l9z3G96G, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_waAZ0Mmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3xd1UcvS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_N4Tq0NjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RKhHpgWm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_s5eGTxba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qwxA3728_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_qwxA3728_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w7dLQtLs, HV_BINOP_DIVIDE, 1, m, &cBinop_w7dLQtLs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jJscFqKQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ZEvWtBGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Wlda7IcJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_At1EG2WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZEvWtBGx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wlda7IcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w7dLQtLs, HV_BINOP_DIVIDE, 0, m, &cBinop_w7dLQtLs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jJscFqKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_At1EG2WU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w7dLQtLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k13dIqZj, HV_BINOP_MULTIPLY, 1, m, &cBinop_k13dIqZj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k13dIqZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m3q3bRXr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qu9y4Gqt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_b1yAxJCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KL3tk5kE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_JaR2TTXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6fG2bB4t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nfA5OPgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_f2mWkTWI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f2mWkTWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k13dIqZj, HV_BINOP_MULTIPLY, 0, m, &cBinop_k13dIqZj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dmk0pgux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_D9EcLW79_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D9EcLW79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CzH4egjZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_js0AXPFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAICxp2P, HV_BINOP_MULTIPLY, 1, m, &cBinop_OAICxp2P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HllQ8Z16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pSo95kO, 1, m, &cVar_7pSo95kO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p0jaJGk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAuh56gT, HV_BINOP_MULTIPLY, 1, m, &cBinop_XAuh56gT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Da2rDMlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vee08w3A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vee08w3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnKCJ6qC, HV_BINOP_MULTIPLY, 1, m, &cBinop_qnKCJ6qC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7pSo95kO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jIjj16U2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_K2znlMqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QcG0ZkTn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nfA5OPgo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sMIt7jw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_eNPo80lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dmk0pgux_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Qu9y4Gqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JaR2TTXw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m3q3bRXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_b1yAxJCq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_KL3tk5kE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZMBbfcuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6fG2bB4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n3DqH6y2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oBwgAoOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rr20Jpr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_CzH4egjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L0pr199y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L0pr199y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsPhVhbu, HV_BINOP_MULTIPLY, 1, m, &cBinop_dsPhVhbu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dsPhVhbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eVCF45ZP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eVCF45ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oBwgAoOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jIjj16U2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_l4JpmeFx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l4JpmeFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B36jPJPP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BA4FiPGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EQdCLEw8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IRXPrH5B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_31SJ5nAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ieyzsTKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OAICxp2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tLh6yK3a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XAuh56gT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_waAZ0Mmu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qnKCJ6qC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N4Tq0NjE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Y6NGUQi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eNPo80lx, 1, m, &cVar_eNPo80lx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yRiEijd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K2znlMqB, 0, m, &cVar_K2znlMqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QcG0ZkTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eNPo80lx, 0, m, &cVar_eNPo80lx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sMIt7jw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pSo95kO, 0, m, &cVar_7pSo95kO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IRXPrH5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31SJ5nAi, HV_BINOP_MULTIPLY, 0, m, &cBinop_31SJ5nAi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B36jPJPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnKCJ6qC, HV_BINOP_MULTIPLY, 0, m, &cBinop_qnKCJ6qC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EQdCLEw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAICxp2P, HV_BINOP_MULTIPLY, 0, m, &cBinop_OAICxp2P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BA4FiPGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAuh56gT, HV_BINOP_MULTIPLY, 0, m, &cBinop_XAuh56gT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jAP7esyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6dhZVZUm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eUT3Ry2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MWuCkLq6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_akYplKEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NPx7xAeC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nUcrnriC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WGKkdpFM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1TbLLD4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wVJhvHXf, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uB7BGauJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mzjwSzaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_mzjwSzaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLwXr45c, HV_BINOP_DIVIDE, 1, m, &cBinop_iLwXr45c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A7v0RS62_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_WNSTKFnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8lbseK59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_e7wFi2Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_WNSTKFnQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8lbseK59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLwXr45c, HV_BINOP_DIVIDE, 0, m, &cBinop_iLwXr45c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A7v0RS62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e7wFi2Ca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iLwXr45c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQJb4YkY, HV_BINOP_MULTIPLY, 1, m, &cBinop_GQJb4YkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GQJb4YkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AmjPBoTt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4JAxHtUO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_bmpy5Tdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qud8gY5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_riNk7gBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f4h94Gct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_S9xIg6kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dVsj29KN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dVsj29KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQJb4YkY, HV_BINOP_MULTIPLY, 0, m, &cBinop_GQJb4YkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SRXSWYWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5vpAKMpj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5vpAKMpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d5aGHQA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BRHVxNwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bw7IFeeh, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bw7IFeeh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3OPayStM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_90eAtKdp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_90eAtKdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BRHVxNwY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uaoZQ0OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p0z0OW7M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p0z0OW7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PT0KLR4i, HV_BINOP_MULTIPLY, 1, m, &cBinop_PT0KLR4i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oG0izY83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdVke2I6, HV_BINOP_MULTIPLY, 1, m, &cBinop_cdVke2I6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YOHdfJiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V6o3hLxz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V6o3hLxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oG0izY83_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0p1L28aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HNCzW6vH, 1, m, &cVar_HNCzW6vH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mpdGBnVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wr1t4ie, HV_BINOP_MULTIPLY, 1, m, &cBinop_8wr1t4ie_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_42icQxFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LqHVjQLS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LqHVjQLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRALEIro, HV_BINOP_MULTIPLY, 1, m, &cBinop_SRALEIro_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_HNCzW6vH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_APqe5orB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_NdsjPjsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28NgX2JM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_S9xIg6kt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RX5dZ5mP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xlAKwqe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SRXSWYWb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AmjPBoTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_bmpy5Tdg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4JAxHtUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_riNk7gBI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_qud8gY5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LcEUblRw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f4h94Gct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qrdbZs8k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wCL2GWez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CsdC4Iwq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_d5aGHQA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DQ0W8dU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DQ0W8dU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bC6HN3kV, HV_BINOP_MULTIPLY, 1, m, &cBinop_bC6HN3kV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bC6HN3kV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_o2vBv8E2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o2vBv8E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wCL2GWez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_APqe5orB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8ORQFjha_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8ORQFjha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cWXNNhZ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DeMgjyZ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FG1qh2mS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cMpU09p0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B4VbEnMz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NDYVWUs0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bw7IFeeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jAP7esyE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PT0KLR4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eUT3Ry2n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cdVke2I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_akYplKEn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8wr1t4ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nUcrnriC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SRALEIro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1TbLLD4p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_HwGAoZPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NdsjPjsU, 0, m, &cVar_NdsjPjsU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5wxQ4gMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xlAKwqe3, 1, m, &cVar_xlAKwqe3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B4VbEnMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PT0KLR4i, HV_BINOP_MULTIPLY, 0, m, &cBinop_PT0KLR4i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DeMgjyZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRALEIro, HV_BINOP_MULTIPLY, 0, m, &cBinop_SRALEIro_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cMpU09p0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdVke2I6, HV_BINOP_MULTIPLY, 0, m, &cBinop_cdVke2I6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cWXNNhZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_NDYVWUs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bw7IFeeh, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bw7IFeeh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FG1qh2mS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wr1t4ie, HV_BINOP_MULTIPLY, 0, m, &cBinop_8wr1t4ie_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RX5dZ5mP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HNCzW6vH, 0, m, &cVar_HNCzW6vH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_28NgX2JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xlAKwqe3, 0, m, &cVar_xlAKwqe3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kaEbzm0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZfWQffjO, 1, m, &cIf_ZfWQffjO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PdW68XwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gZfq6fEW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dSnNvB9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PdW68XwY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Xwnp6mC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZfWQffjO, 0, m, &cIf_ZfWQffjO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_OnyQM8cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6HQ3Frx9, HV_BINOP_DIVIDE, 0, m, &cBinop_6HQ3Frx9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_OVIj0N6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SBJiCI87, HV_BINOP_DIVIDE, 1, m, &cBinop_SBJiCI87_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6HQ3Frx9, HV_BINOP_DIVIDE, 1, m, &cBinop_6HQ3Frx9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_eh8cfsQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HOTPFTk2, HV_BINOP_DIVIDE, 0, m, &cBinop_HOTPFTk2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_iIB7eQmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HOTPFTk2, HV_BINOP_DIVIDE, 1, m, &cBinop_HOTPFTk2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_o91ubIxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OnyQM8cm, 0, m, &cVar_OnyQM8cm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w8hcRP2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OVIj0N6U, 0, m, &cVar_OVIj0N6U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vw9Oql5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SBJiCI87, HV_BINOP_DIVIDE, 0, m, &cBinop_SBJiCI87_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SBJiCI87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_eh8cfsQy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6HQ3Frx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_iIB7eQmg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HOTPFTk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_DrTqG63D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_i2ERnATA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_NFJIbwPE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rhrsYmIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_zJikXy2s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DrTqG63D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rhrsYmIi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zJikXy2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_i2ERnATA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NFJIbwPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Um1kfAMF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_BqGv321I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_52BJ70rN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WR3nE1aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hqglgYRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_NZfiCrJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QE5M4hI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_8sCfmeor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GMqc3ca5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Ur7hKarP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oWlVEmag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_lXlosFqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rJ4OHUxB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_TtcbpTZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nfZsTeqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_MOIvVWGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ojh26X5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_qwEzmZIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_siukLmhd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_d2hIslPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jKVWneXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_UM1p4zVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PccNiE60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9jfWhuJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8z83RiLQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3vqXqaVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_l49gKgGQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l49gKgGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_h17JiAIT, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_z2KTnLyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eA6qNvDV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_eA6qNvDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ebHxfAQu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_XJinl2AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bx2jHpc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_YXECkuQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_R8p6Pd2A_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BQEJomr3, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ebHxfAQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CsaBpDma, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bx2jHpc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YXECkuQ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R8p6Pd2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_O1vPm5rT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zArLtvHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dmr22ybG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_dmr22ybG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1hy6Rfu0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bfLNrKmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kh6vjU6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_k4Dj3kuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kbyGtuGC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gi8oFntE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1hy6Rfu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1hj3hTxT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Kh6vjU6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k4Dj3kuc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kbyGtuGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wknQVfG0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PcpkK1y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0zRxsyID_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0zRxsyID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_lqm2V9hw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_IaB87jeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_062rg2Zs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_0fB5Qoh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wb5xHLYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lqm2V9hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cGzncQtu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cGzncQtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TGZGQoxV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fj3qZaok_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TGZGQoxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wFGI7Dpa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fj3qZaok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ABlrP9I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wFGI7Dpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VlMEBNfd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3ABlrP9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FPwQQewn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FPwQQewn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KN9OOdbY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VlMEBNfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_IaB87jeA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KN9OOdbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_0fB5Qoh4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uVISOg8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tMMYQjcs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tMMYQjcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tM2sTqeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_euk3SOAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_57VlAs9Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_57VlAs9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IeJHPS6I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_A4zLXwfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A4zLXwfM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dxgnPMhP, 0, m, &cDelay_dxgnPMhP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A4zLXwfM, 0, m, &cDelay_A4zLXwfM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2JkYf5kj, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_dxgnPMhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dxgnPMhP, m);
  cMsg_QLqiUamE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mB2P9sjM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZukGKdba_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_DpfqUQ4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QFrj2YNB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_AA4shJCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PCXmyjwS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A4zLXwfM, 2, m, &cDelay_A4zLXwfM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S3lwJNrz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QFrj2YNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_AA4shJCi, 0, m, &hTable_AA4shJCi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IeJHPS6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_DpfqUQ4r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QLqiUamE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_AA4shJCi, 0, m, &hTable_AA4shJCi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_S3lwJNrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A4zLXwfM, 0, m, &cDelay_A4zLXwfM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PCXmyjwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dxgnPMhP, 2, m, &cDelay_dxgnPMhP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZukGKdba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2JkYf5kj, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CuJH9mlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4nAf5sEa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4nAf5sEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7Ah5R9wr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_6rGeACSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6rGeACSG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3gqK5UHS, 0, m, &cDelay_3gqK5UHS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rGeACSG, 0, m, &cDelay_6rGeACSG_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hmxRPtT2, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_3gqK5UHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3gqK5UHS, m);
  cMsg_6S7Tnaf2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_iy4JTSzZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TRnB9csq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bt0Wno3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dUCUQb7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_9SiOdIIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VzPjXJit_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rGeACSG, 2, m, &cDelay_6rGeACSG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PmzN2MmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dUCUQb7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_9SiOdIIo, 0, m, &hTable_9SiOdIIo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7Ah5R9wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_bt0Wno3v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6S7Tnaf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_9SiOdIIo, 0, m, &hTable_9SiOdIIo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PmzN2MmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rGeACSG, 0, m, &cDelay_6rGeACSG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VzPjXJit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3gqK5UHS, 2, m, &cDelay_3gqK5UHS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TRnB9csq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hmxRPtT2, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_qS2cMmBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PH07UXv, HV_BINOP_MULTIPLY, 0, m, &cBinop_0PH07UXv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9XiFR6yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xu8PZ4bd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Xu8PZ4bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3UrisGLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0PH07UXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BFioEvJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qctVDo61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PH07UXv, HV_BINOP_MULTIPLY, 1, m, &cBinop_0PH07UXv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3UrisGLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qctVDo61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BFioEvJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pTiQAiXt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pTiQAiXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EkdVljKE_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6Eoi1uUn, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EkdVljKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5WBO2t6t, m);
}

void Heavy_WSTD_FL3NGR::cVar_PcNXVnh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oW6u4x3A, HV_BINOP_MULTIPLY, 0, m, &cBinop_oW6u4x3A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8Klaw0Zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3g5HDmn5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3g5HDmn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4LeE4YTG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oW6u4x3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8F9UttkD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JJ9bO11l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oW6u4x3A, HV_BINOP_MULTIPLY, 1, m, &cBinop_oW6u4x3A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4LeE4YTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JJ9bO11l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8F9UttkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qUi8tpLR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qUi8tpLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LUlWAGpQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d9UPokQz, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LUlWAGpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_u76IkWBj, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tM2sTqeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zaq0nUzN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_NCc27zDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_ibSdOmLG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_89lUaFgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZkjkSXUm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZTJYR0gM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_NCc27zDs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FySU5x1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rFf9LdTm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rFf9LdTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zqVvdEwr, HV_BINOP_MULTIPLY, 1, m, &cBinop_zqVvdEwr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZkjkSXUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_FySU5x1r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zqVvdEwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MV9QerRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ibSdOmLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zqVvdEwr, HV_BINOP_MULTIPLY, 0, m, &cBinop_zqVvdEwr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MV9QerRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zqaEaXtV, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Tau4I6iX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_pQxddx7j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pQxddx7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_89lUaFgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTJYR0gM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5hWnBDZ9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4uYXVF8N, 0, m, &cSlice_4uYXVF8N_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YG8p2mBm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4uYXVF8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RDeoOIGj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RDeoOIGj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gQ9YanAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RDeoOIGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RDeoOIGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ePUamXjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YG8p2mBm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nX01bbgX, 0, m, &cSlice_nX01bbgX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dQrNa4K8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_nX01bbgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s3r4rw8X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s3r4rw8X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ORbH7O0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s3r4rw8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_s3r4rw8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_at7vqOdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_dQrNa4K8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UmWKot7x, 0, m, &cSlice_UmWKot7x_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zOs4PXEb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_UmWKot7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CkAQH5jp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CkAQH5jp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gE3S6EvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CkAQH5jp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CkAQH5jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4QYjJc1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zOs4PXEb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ns1gK6jo, 0, m, &cSlice_Ns1gK6jo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Ns1gK6jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uftDLzGu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uftDLzGu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_D5Hxb0Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uftDLzGu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_uftDLzGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gPlX2Eji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_062rg2Zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rPUDUEG3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wb5xHLYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P0Mfg4Ec, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_JrsD6Gxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_a7ARpfEv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a7ARpfEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_8dsSmdTm, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_K8CuxCfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f27YeJp8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_f27YeJp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hqdePTs8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_fqDJewAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qIqudJ9Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_oiB5tSa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NIGtP49p_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nekstxRO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hqdePTs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BjI8vW33, m);
}

void Heavy_WSTD_FL3NGR::cMsg_qIqudJ9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oiB5tSa9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NIGtP49p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CHvp6awN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wMo1IGR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pM8LQCYe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_pM8LQCYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_noySZn7j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_F53PfuYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RZA6Zl7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_tei0MxGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nXIRgX1E_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_A6LwWjAE, m);
}

void Heavy_WSTD_FL3NGR::cBinop_noySZn7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_k4uIJ9y8, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RZA6Zl7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tei0MxGk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nXIRgX1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aE7aZS41, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pV0DiEHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_e2PBMEzT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e2PBMEzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_sPJ9MDaE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NIgAiBWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2H34buQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3CFghP7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LtAD5x9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sPJ9MDaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IwO0qs3f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IwO0qs3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MeKKjvKD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ohjRd7SA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MeKKjvKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kGs8xSPX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ohjRd7SA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_51AeQyFy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kGs8xSPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uwV5sRk9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_51AeQyFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hdt5Wt8j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hdt5Wt8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mTvV2Jo3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uwV5sRk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_NIgAiBWr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mTvV2Jo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3CFghP7v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5cDdMGXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rE5os2nl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rE5os2nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OevYAUJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZVU4hdV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SPV5JYIl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SPV5JYIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CkDvN5V5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_c31MRwQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c31MRwQB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KrqwUk2p, 0, m, &cDelay_KrqwUk2p_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_c31MRwQB, 0, m, &cDelay_c31MRwQB_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4UrT5L2r, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_KrqwUk2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KrqwUk2p, m);
  cMsg_eiZFHOgP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cqF1Ei0Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TZHuRP67_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_cplwipcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JW4qtady_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_xRemz9SB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AXEaUZev_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_c31MRwQB, 2, m, &cDelay_c31MRwQB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t62cmTZs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JW4qtady_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_xRemz9SB, 0, m, &hTable_xRemz9SB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CkDvN5V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_cplwipcJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eiZFHOgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_xRemz9SB, 0, m, &hTable_xRemz9SB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_t62cmTZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c31MRwQB, 0, m, &cDelay_c31MRwQB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AXEaUZev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_KrqwUk2p, 2, m, &cDelay_KrqwUk2p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TZHuRP67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4UrT5L2r, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_puNpm34U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_drWG4hzG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_drWG4hzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CVAOWQ1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_2NswOnr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2NswOnr3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wp12Lz90, 0, m, &cDelay_wp12Lz90_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NswOnr3, 0, m, &cDelay_2NswOnr3_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YavB9NjT, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_wp12Lz90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wp12Lz90, m);
  cMsg_hHMxNKUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Yc6cx64z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wG44ixRR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ni48hs8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uHv63Kjw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_aJGw1f4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FPj816Su_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NswOnr3, 2, m, &cDelay_2NswOnr3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JNSrhFkJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uHv63Kjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_aJGw1f4X, 0, m, &hTable_aJGw1f4X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CVAOWQ1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ni48hs8v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hHMxNKUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_aJGw1f4X, 0, m, &hTable_aJGw1f4X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JNSrhFkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NswOnr3, 0, m, &cDelay_2NswOnr3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FPj816Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wp12Lz90, 2, m, &cDelay_wp12Lz90_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wG44ixRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YavB9NjT, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_ENQ37kdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmSPDLmC, HV_BINOP_MULTIPLY, 0, m, &cBinop_KmSPDLmC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1mPFhGkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NWDan0Eq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_NWDan0Eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y4tvPNCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KmSPDLmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nXT5F8Lz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ttzXtn4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmSPDLmC, HV_BINOP_MULTIPLY, 1, m, &cBinop_KmSPDLmC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y4tvPNCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ttzXtn4a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nXT5F8Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fEiGpxVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fEiGpxVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AzrqJpkA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wrSXKCNT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AzrqJpkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hnfPUZpA, m);
}

void Heavy_WSTD_FL3NGR::cVar_SRo2qcBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NnapEAPt, HV_BINOP_MULTIPLY, 0, m, &cBinop_NnapEAPt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DLLAspBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l28pxcNg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_l28pxcNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_knZJVw9s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NnapEAPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Rb47h0PL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pJvVSpI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NnapEAPt, HV_BINOP_MULTIPLY, 1, m, &cBinop_NnapEAPt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_knZJVw9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pJvVSpI3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Rb47h0PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HD2U25x0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HD2U25x0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QzcBQFr6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_f7pxTTym, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QzcBQFr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_O69oYIya, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OevYAUJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cCfkwZTe, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_drQed4oA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_wbAMzGgV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QON9tvJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SbiQLtW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Nv2QisJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_drQed4oA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J2tVZFD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EVJ5BOuG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EVJ5BOuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CKJHWWzy, HV_BINOP_MULTIPLY, 1, m, &cBinop_CKJHWWzy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SbiQLtW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_J2tVZFD4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CKJHWWzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yQCeQqg1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wbAMzGgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CKJHWWzy, HV_BINOP_MULTIPLY, 0, m, &cBinop_CKJHWWzy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yQCeQqg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uuvGMqGL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Ritn5YTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_6nhgm82z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6nhgm82z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QON9tvJj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nv2QisJN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jzXulmcM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dCBfpa2G, 0, m, &cSlice_dCBfpa2G_sendMessage);
      break;
    }
    default: {
      cSwitchcase_malF6qxH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dCBfpa2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_g3OjU3Ex_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_g3OjU3Ex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZveilipA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g3OjU3Ex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_g3OjU3Ex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9gCY3PGs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_malF6qxH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UqveeThz, 0, m, &cSlice_UqveeThz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kVLnCmcq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_UqveeThz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_F85xFe1n_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_F85xFe1n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qbtmk3CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F85xFe1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_F85xFe1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DsJtSQ8A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_kVLnCmcq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jdMhZ9XQ, 0, m, &cSlice_jdMhZ9XQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TMTzLeON_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jdMhZ9XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ghDXIZwm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ghDXIZwm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_loZIqhCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ghDXIZwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ghDXIZwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zgbxyvpM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_TMTzLeON_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ndV0DrXJ, 0, m, &cSlice_ndV0DrXJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ndV0DrXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Wz2KLoeC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Wz2KLoeC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_MEihEccB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Wz2KLoeC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Wz2KLoeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_awxJEKg6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_2H34buQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xcTrSe8n, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LtAD5x9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5g7oCfGF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_orugX9FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wxISiojV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wxISiojV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Kb883rjK, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_6fOY1hAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_e89AP518_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_e89AP518_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9bTW3kcu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3jvLIMQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xG0iwbJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_Ub4WE7I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PCYMPTmo_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5SC49wqf, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9bTW3kcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2i0574eM, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xG0iwbJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ub4WE7I5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PCYMPTmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LUxRULWN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pRlCkqek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nR6Vlp5o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_nR6Vlp5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IuYo4vmu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_SUyzCL4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Wyqcbmx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_8zOo19GJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_P5wqRpwH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1DYUibun, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IuYo4vmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PZZSgZXT, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5Wyqcbmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8zOo19GJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P5wqRpwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_N1uFO8QT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WlM1oK3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_RekJGBEB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RekJGBEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ofG9CtF7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Z9sEcf1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WOHH95y2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_TKaKCPKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mq5lZrMY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ofG9CtF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_v6elRlS6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v6elRlS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JFfGgo1T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V1grTOA0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JFfGgo1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_emHopdj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_V1grTOA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yaMo0MXU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_emHopdj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8hfL83yr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yaMo0MXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9jn3U90Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9jn3U90Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_flbEDiDl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8hfL83yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Z9sEcf1F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_flbEDiDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_TKaKCPKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xJ5zDblt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xn4zCpfW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xn4zCpfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iGWRVoQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ig9Fbll9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0Aau5cqt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0Aau5cqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4KYiK21Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_qSJlB9xE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qSJlB9xE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rnelccKX, 0, m, &cDelay_rnelccKX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSJlB9xE, 0, m, &cDelay_qSJlB9xE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oTtdnt5d, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_rnelccKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rnelccKX, m);
  cMsg_MSq2CXcJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zSUkkMRV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gzQd6a7b_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_1zU7y985_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2OkcWIwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_EEcgzlii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WfADZfpR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSJlB9xE, 2, m, &cDelay_qSJlB9xE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yLLSX28K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2OkcWIwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_EEcgzlii, 0, m, &hTable_EEcgzlii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4KYiK21Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_1zU7y985_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MSq2CXcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_EEcgzlii, 0, m, &hTable_EEcgzlii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yLLSX28K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qSJlB9xE, 0, m, &cDelay_qSJlB9xE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WfADZfpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_rnelccKX, 2, m, &cDelay_rnelccKX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gzQd6a7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oTtdnt5d, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mZ8Gq9E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SK7WrdYa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SK7WrdYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cWtx9xfw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_bccOCsII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bccOCsII, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1b3MCamL, 0, m, &cDelay_1b3MCamL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bccOCsII, 0, m, &cDelay_bccOCsII_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cPNbFZsn, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_1b3MCamL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1b3MCamL, m);
  cMsg_juaMck60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PqfQPgiE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_csdP3xFz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wgclamZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1xz1EqMT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_2H2Gicw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZxBZegTi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bccOCsII, 2, m, &cDelay_bccOCsII_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uC4f7198_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1xz1EqMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2H2Gicw2, 0, m, &hTable_2H2Gicw2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cWtx9xfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_wgclamZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_juaMck60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2H2Gicw2, 0, m, &hTable_2H2Gicw2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uC4f7198_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bccOCsII, 0, m, &cDelay_bccOCsII_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZxBZegTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1b3MCamL, 2, m, &cDelay_1b3MCamL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_csdP3xFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cPNbFZsn, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_9Lj2uQmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ABE4ZZNd, HV_BINOP_MULTIPLY, 0, m, &cBinop_ABE4ZZNd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SGmdosVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lsb3b5Pd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lsb3b5Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZzSky8uF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ABE4ZZNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dRZDDHa2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AvsZmiif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ABE4ZZNd, HV_BINOP_MULTIPLY, 1, m, &cBinop_ABE4ZZNd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZzSky8uF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AvsZmiif_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dRZDDHa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7IKh1df9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7IKh1df9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hWCdBqU3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NqPcKeBk, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hWCdBqU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bFXRANhJ, m);
}

void Heavy_WSTD_FL3NGR::cVar_OkYSj4CA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1BPsQ5CZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_1BPsQ5CZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_j9B683a3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xpx2MWt5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Xpx2MWt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FV9phLJd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1BPsQ5CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_t47Wldxm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_REEXK22n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1BPsQ5CZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_1BPsQ5CZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FV9phLJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_REEXK22n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t47Wldxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Bk1H58fj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bk1H58fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_p43PXn4P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uCLm1wfe, m);
}

void Heavy_WSTD_FL3NGR::cBinop_p43PXn4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qA2sdsgy, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iGWRVoQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jjf81G4B, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_QKKTd5eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_6LH5QCb2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SatB8NpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9xPr9kiX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Q8DjKbxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_QKKTd5eV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Be8CviKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PixW4DEw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PixW4DEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HFN7HFbR, HV_BINOP_MULTIPLY, 1, m, &cBinop_HFN7HFbR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9xPr9kiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Be8CviKz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HFN7HFbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FhNS6KWG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6LH5QCb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HFN7HFbR, HV_BINOP_MULTIPLY, 0, m, &cBinop_HFN7HFbR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FhNS6KWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fpwywKzm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Qz4oTLK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_zGEXE1tf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zGEXE1tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SatB8NpH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8DjKbxJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_uoVGAUtZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C7fP7qzU, 0, m, &cSlice_C7fP7qzU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AE8wWNbz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_C7fP7qzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Lc0DcNIw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Lc0DcNIw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_c5n3GTy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lc0DcNIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Lc0DcNIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8ugMUsqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_AE8wWNbz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3f21Z4JY, 0, m, &cSlice_3f21Z4JY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Jac7Z4Ot_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_3f21Z4JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OKrsYIN6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OKrsYIN6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_PExtsJSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OKrsYIN6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_OKrsYIN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8L9V06NE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Jac7Z4Ot_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B0E0FROt, 0, m, &cSlice_B0E0FROt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7HmRB5t1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_B0E0FROt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eSXY8QlT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eSXY8QlT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ePLhgVvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eSXY8QlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_eSXY8QlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_exkgaWNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7HmRB5t1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Wex9zPBI, 0, m, &cSlice_Wex9zPBI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Wex9zPBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8qctJ0IS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8qctJ0IS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lWYPA2s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8qctJ0IS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_8qctJ0IS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jXZXLAB9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WOHH95y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K96dbwIc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mq5lZrMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gPtPQD5t, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TYiTbqQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PoZEBCOp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Bvo0NhnV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_O3mjKwYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PoZEBCOp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Bvo0NhnV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_msazJMHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PoZEBCOp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Bvo0NhnV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WoLfuJk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PoZEBCOp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Bvo0NhnV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Um1kfAMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PoZEBCOp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Bvo0NhnV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HAwhhjBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BBW1cT6f, 0, m, &cVar_BBW1cT6f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VJJnMXUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dXwF3Hdi, 0, m, &cVar_dXwF3Hdi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MG4yflGY, 0, m, &cVar_MG4yflGY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yGPjaGVC, 0, m, &cVar_yGPjaGVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GMqc3ca5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5hWnBDZ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_52BJ70rN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5hWnBDZ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hqglgYRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5hWnBDZ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QE5M4hI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5hWnBDZ9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_gw2v3Sq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8sCfmeor, 0, m, &cVar_8sCfmeor_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lo4WH7li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BqGv321I, 0, m, &cVar_BqGv321I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3u0zNPJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NZfiCrJy, 0, m, &cVar_NZfiCrJy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Ojh26X5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jzXulmcM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oWlVEmag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jzXulmcM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rJ4OHUxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jzXulmcM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nfZsTeqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jzXulmcM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_00EHFrWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MOIvVWGB, 0, m, &cVar_MOIvVWGB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pbTq323O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ur7hKarP, 0, m, &cVar_Ur7hKarP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QVdCG8wC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TtcbpTZt, 0, m, &cVar_TtcbpTZt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8z83RiLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uoVGAUtZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_siukLmhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uoVGAUtZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jKVWneXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uoVGAUtZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PccNiE60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uoVGAUtZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_LXt0At5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9jfWhuJH, 0, m, &cVar_9jfWhuJH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5WjKJsBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qwEzmZIF, 0, m, &cVar_qwEzmZIF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_das5dMj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UM1p4zVT, 0, m, &cVar_UM1p4zVT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yVSMKXA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dXwF3Hdi, 0, m, &cVar_dXwF3Hdi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cigezggC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MG4yflGY, 0, m, &cVar_MG4yflGY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_d5bVQxxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yGPjaGVC, 0, m, &cVar_yGPjaGVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qCcxOULd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aKYb9ty8, 0, m, &cVar_aKYb9ty8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RCkb9ZQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3dTubaY3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rcr0eHnA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4KJ2adqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3LUzS1RF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KfS1DNmD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XQmvvPEv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lxP38UvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s4txK3Gm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3yBDYsCS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nd7eZphD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sI35VSli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_snOvMA3F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p1lTNt9H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvqElil3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9fNEqTEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wt8NnjjN_sendMessage(_c, 0, m);
  cMsg_tPaBsBIF_sendMessage(_c, 0, m);
  cMsg_HHNLpC8E_sendMessage(_c, 0, m);
  cMsg_PLkO6NNB_sendMessage(_c, 0, m);
  cMsg_s5eGTxba_sendMessage(_c, 0, m);
  cMsg_uB7BGauJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TZWrBmQo, 0, m, &cVar_TZWrBmQo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aKYb9ty8, 0, m, &cVar_aKYb9ty8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YnCDq4oz, 0, m, &cVar_YnCDq4oz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jHGyrbq0, 0, m, &cVar_jHGyrbq0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K2znlMqB, 0, m, &cVar_K2znlMqB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NdsjPjsU, 0, m, &cVar_NdsjPjsU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5LJ64RjL, 0, m, &cVar_5LJ64RjL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KizvPPMV, 0, m, &cVar_KizvPPMV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EHklSnDd, 0, m, &cVar_EHklSnDd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LBKpdUWs, 0, m, &cVar_LBKpdUWs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3joznFCe, 0, m, &cVar_3joznFCe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ibb4S6Tn, 0, m, &cVar_Ibb4S6Tn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IcvhbB1T, 0, m, &cVar_IcvhbB1T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vUY3V6Sq, 0, m, &cVar_vUY3V6Sq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AMn1G9fI, 0, m, &cVar_AMn1G9fI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SzA5eJeM, 0, m, &cVar_SzA5eJeM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DsACsuEF, 0, m, &cVar_DsACsuEF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lJcahoLI, 0, m, &cVar_lJcahoLI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EGBzzZMr, 0, m, &cVar_EGBzzZMr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6fP3f8AE, 0, m, &cVar_6fP3f8AE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c7R1jqbw, 0, m, &cVar_c7R1jqbw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F2EbRZZt, 0, m, &cVar_F2EbRZZt_sendMessage);
  cMsg_9XiFR6yo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qS2cMmBg, 0, m, &cVar_qS2cMmBg_sendMessage);
  cMsg_8Klaw0Zc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PcNXVnh9, 0, m, &cVar_PcNXVnh9_sendMessage);
  cMsg_1mPFhGkR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ENQ37kdn, 0, m, &cVar_ENQ37kdn_sendMessage);
  cMsg_DLLAspBc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SRo2qcBV, 0, m, &cVar_SRo2qcBV_sendMessage);
  cMsg_SGmdosVw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9Lj2uQmL, 0, m, &cVar_9Lj2uQmL_sendMessage);
  cMsg_j9B683a3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OkYSj4CA, 0, m, &cVar_OkYSj4CA_sendMessage);
  cMsg_euk3SOAi_sendMessage(_c, 0, m);
  cMsg_CuJH9mlw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gQ9YanAq, 0, m, &cVar_gQ9YanAq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ORbH7O0o, 0, m, &cVar_ORbH7O0o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gE3S6EvI, 0, m, &cVar_gE3S6EvI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D5Hxb0Nw, 0, m, &cVar_D5Hxb0Nw_sendMessage);
  cMsg_ZVU4hdV8_sendMessage(_c, 0, m);
  cMsg_puNpm34U_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZveilipA, 0, m, &cVar_ZveilipA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qbtmk3CK, 0, m, &cVar_qbtmk3CK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_loZIqhCH, 0, m, &cVar_loZIqhCH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MEihEccB, 0, m, &cVar_MEihEccB_sendMessage);
  cMsg_ig9Fbll9_sendMessage(_c, 0, m);
  cMsg_mZ8Gq9E1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_c5n3GTy8, 0, m, &cVar_c5n3GTy8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PExtsJSA, 0, m, &cVar_PExtsJSA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ePLhgVvF, 0, m, &cVar_ePLhgVvF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lWYPA2s7, 0, m, &cVar_lWYPA2s7_sendMessage);
  cMsg_VJJnMXUK_sendMessage(_c, 0, m);
  cMsg_HAwhhjBo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XJinl2AH, 0, m, &cVar_XJinl2AH_sendMessage);
  cMsg_z2KTnLyf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bfLNrKmw, 0, m, &cVar_bfLNrKmw_sendMessage);
  cMsg_zArLtvHh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fqDJewAF, 0, m, &cVar_fqDJewAF_sendMessage);
  cMsg_K8CuxCfX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F53PfuYx, 0, m, &cVar_F53PfuYx_sendMessage);
  cMsg_wMo1IGR8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3jvLIMQx, 0, m, &cVar_3jvLIMQx_sendMessage);
  cMsg_6fOY1hAC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SUyzCL4G, 0, m, &cVar_SUyzCL4G_sendMessage);
  cMsg_pRlCkqek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_SNEnHwub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyIpLkSo, HV_BINOP_MULTIPLY, 0, m, &cBinop_vyIpLkSo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2zfhajvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Npxs9Mg5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CgwzsLgt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TMQso3wj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_v4ZFJWJH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fOKEj4vP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yMvcMVTF_sendMessage);
  cMsg_yiXJyg5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_sKbARoA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dj6nsWAw, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dj6nsWAw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6VVhWLY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_QytFu2LT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uXrSWi9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbZ6r5XQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_lbZ6r5XQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YTfWLSXn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g33rHdUw_sendMessage);
  cMsg_zEJCw4aj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_eLHe9x0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OqQeX7np, HV_BINOP_MULTIPLY, 0, m, &cBinop_OqQeX7np_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7Bu4nxAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MpXvrXnr_sendMessage(_c, 0, m);
  cMsg_8gOCXTDs_sendMessage(_c, 0, m);
  cMsg_iD6yjPSD_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iDlM9ezX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9yaPa3lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wByl5ad4_sendMessage);
  cMsg_cm0bPX6A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_mTWlf0EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K2znlMqB, 0, m, &cVar_K2znlMqB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uMq0VuN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y6NGUQi9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yRiEijd4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2ygR4zOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dYNdHD6B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pIjGvLTJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vHZfguQc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UGhSDnkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iDacmOcD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6H205tuq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uWk4FCrg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wWOL0tLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8LXI6iBo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5LzGI8Dp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iJWrGrm9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zjSDQfJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u09389BI, HV_BINOP_MULTIPLY, 0, m, &cBinop_u09389BI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_up7NDajh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_akjr4fUp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rJesLAQU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g3uTi0qF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_U2IQOfig_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tbXQfdkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Z2ZVs8XD_sendMessage);
  cMsg_jANMMVyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_ZMBbfcuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsPhVhbu, HV_BINOP_MULTIPLY, 0, m, &cBinop_dsPhVhbu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_n3DqH6y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_p0jaJGk1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Rr20Jpr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31SJ5nAi, HV_BINOP_MULTIPLY, 1, m, &cBinop_31SJ5nAi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_js0AXPFJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HllQ8Z16_sendMessage);
  cMsg_Da2rDMlJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_LcEUblRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bC6HN3kV, HV_BINOP_MULTIPLY, 0, m, &cBinop_bC6HN3kV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qrdbZs8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3OPayStM_sendMessage(_c, 0, m);
  cMsg_uaoZQ0OY_sendMessage(_c, 0, m);
  cMsg_YOHdfJiz_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_mpdGBnVx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CsdC4Iwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0p1L28aC_sendMessage);
  cMsg_42icQxFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_nGopQ7J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BBW1cT6f, 0, m, &cVar_BBW1cT6f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aJcDJ3Mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gw2v3Sq9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zsO3VpAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Lo4WH7li_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0vdm41Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WR3nE1aO, 0, m, &cVar_WR3nE1aO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Tm1lJzLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_3u0zNPJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zgj9QWw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_00EHFrWo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_p8RnUOsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pbTq323O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gIX4wRow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lXlosFqv, 0, m, &cVar_lXlosFqv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Yx2Y9VaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QVdCG8wC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Tr3uZITp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LXt0At5g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5HPRMv1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_5WjKJsBs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_36hcZHRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d2hIslPb, 0, m, &cVar_d2hIslPb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_va9ftMeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_das5dMj8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4QYjJc1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_3vqXqaVv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_at7vqOdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Tau4I6iX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gPlX2Eji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PcpkK1y8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ePUamXjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uVISOg8F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zgbxyvpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_JrsD6Gxx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DsJtSQ8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Ritn5YTH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_awxJEKg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pV0DiEHA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9gCY3PGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5cDdMGXD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_exkgaWNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_orugX9FS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8L9V06NE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Qz4oTLK1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jXZXLAB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WlM1oK3n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8ugMUsqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xJ5zDblt_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_aB4F40Uj, VOf(Bf0));
    __hv_line_f(&sLine_wVk5m1tO, VOf(Bf1));
    __hv_line_f(&sLine_YMC7ACrZ, VOf(Bf2));
    __hv_line_f(&sLine_RMkKteqv, VOf(Bf3));
    __hv_line_f(&sLine_qAiWyODa, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_nYwOu8kh, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_PGqFoDMh, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Jzt7Ph5f, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_PxNrIp2u, VOf(Bf1));
    __hv_line_f(&sLine_mdkacVLD, VOf(Bf0));
    __hv_line_f(&sLine_y2fK15m7, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_uDuB02ut, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_LMDgBnFm, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_oOlXw7Z1, VOf(Bf5));
    __hv_line_f(&sLine_CDGuBsmJ, VOf(Bf1));
    __hv_line_f(&sLine_wWUx7lql, VOf(Bf2));
    __hv_line_f(&sLine_GN4ERnPJ, VOf(Bf4));
    __hv_line_f(&sLine_xPPhsSBG, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_ok3X9COn, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_emc5bTWW, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_zFsq0XFv, VOf(Bf6));
    __hv_line_f(&sLine_DfoUuMms, VOf(Bf2));
    __hv_line_f(&sLine_MteCRcdY, VOf(Bf1));
    __hv_line_f(&sLine_tVy4reZj, VOf(Bf5));
    __hv_line_f(&sLine_YdOQ3GOb, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_cx4l47tR, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_Iy2UWw4f, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_IERXvBl5, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_l9z3G96G, VOf(Bf2));
    __hv_line_f(&sLine_3xd1UcvS, VOf(Bf6));
    __hv_line_f(&sLine_RKhHpgWm, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_edb34Mzw, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_gZfq6fEW, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_6dhZVZUm, VOf(Bf8));
    __hv_line_f(&sLine_MWuCkLq6, VOf(Bf2));
    __hv_line_f(&sLine_NPx7xAeC, VOf(Bf1));
    __hv_line_f(&sLine_WGKkdpFM, VOf(Bf7));
    __hv_line_f(&sLine_wVJhvHXf, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_kOstou5l, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qCbhLUhd, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_P0Mfg4Ec, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_h17JiAIT, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Zaq0nUzN, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_6Eoi1uUn, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5WBO2t6t, VOf(Bf8));
    __hv_rpole_f(&sRPole_Zfb8sbgo, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_d9UPokQz, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_u76IkWBj, VOf(Bf10));
    __hv_rpole_f(&sRPole_4LpyLQb4, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_Ezmxeb2k, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_CsaBpDma, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_O1vPm5rT, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_BQEJomr3, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_bPFJZwaq, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_jH1l1Cgn, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_rPUDUEG3, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_6YX4vaWK, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_1hj3hTxT, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_wknQVfG0, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_gi8oFntE, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_9WAfr1QA, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_BsqqcfDe, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_zqaEaXtV, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_2JkYf5kj, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_hmxRPtT2, VIf(Bf3));
    __hv_varwrite_f(&sVarf_HIl156L8, VIf(Bf11));
    __hv_line_f(&sLine_5g7oCfGF, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_8dsSmdTm, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_cCfkwZTe, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_wrSXKCNT, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_hnfPUZpA, VOf(Bf10));
    __hv_rpole_f(&sRPole_KBNLnQGW, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_f7pxTTym, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_O69oYIya, VOf(Bf5));
    __hv_rpole_f(&sRPole_0JzeGFdp, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_gdJ97cde, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_BjI8vW33, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_CHvp6awN, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_nekstxRO, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ieqcZOVt, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_6ohxTFT8, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_xcTrSe8n, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_ssymQ1vx, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_k4uIJ9y8, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_aE7aZS41, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_A6LwWjAE, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_BZBWt3tI, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_kKbfvm92, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_uuvGMqGL, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_4UrT5L2r, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_YavB9NjT, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5v89fuST, VIf(Bf8));
    __hv_line_f(&sLine_gPtPQD5t, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_Kb883rjK, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_jjf81G4B, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_NqPcKeBk, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_bFXRANhJ, VOf(Bf5));
    __hv_rpole_f(&sRPole_E1R8aDFq, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_uCLm1wfe, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_qA2sdsgy, VOf(Bf6));
    __hv_rpole_f(&sRPole_qcTBumQj, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_qNaTVyBH, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_2i0574eM, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_LUxRULWN, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_5SC49wqf, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_lMhRJz4N, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_SZSSyrUk, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_K96dbwIc, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_5OvoAjRm, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_PZZSgZXT, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_N1uFO8QT, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_1DYUibun, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_YFdOaX4j, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_EWnt9Yeg, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_fpwywKzm, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_oTtdnt5d, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_cPNbFZsn, VIf(Bf4));
    __hv_varwrite_f(&sVarf_N9nrIX1R, VIf(Bf10));
    __hv_varwrite_f(&sVarf_XMpIVazP, VIf(Bf2));
    __hv_varwrite_f(&sVarf_6gaHLj7u, VIf(Bf9));
    __hv_varwrite_f(&sVarf_sKeqpVl8, VIf(Bf11));
    __hv_varread_f(&sVarf_HIl156L8, VOf(Bf11));
    __hv_varread_f(&sVarf_5v89fuST, VOf(Bf9));
    __hv_varread_f(&sVarf_N9nrIX1R, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_XMpIVazP, VOf(Bf2));
    __hv_varread_f(&sVarf_6gaHLj7u, VOf(Bf11));
    __hv_varread_f(&sVarf_sKeqpVl8, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
